==> tencentcloud-sdk-java-3.0.41-sources.jar: com/tencentcloudapi/cws/v20180312/models/DeleteMonitorsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteMonitorsRequest  extends AbstractModel{

    /**
    * 监控任务ID列表
    */
    @SerializedName("MonitorIds")
    @Expose
    private Integer [] MonitorIds;

    /**
     * 获取监控任务ID列表
     * @return MonitorIds 监控任务ID列表
     */
    public Integer [] getMonitorIds() {
        return this.MonitorIds;
    }

    /**
     * 设置监控任务ID列表
     * @param MonitorIds 监控任务ID列表
     */
    public void setMonitorIds(Integer [] MonitorIds) {
        this.MonitorIds = MonitorIds;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "MonitorIds.", this.MonitorIds);

    }
}

==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/cws/v20180312/models/DeleteMonitorsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cws.v20180312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteMonitorsRequest extends AbstractModel{

    /**
    * 监控任务ID列表
    */
    @SerializedName("MonitorIds")
    @Expose
    private Long [] MonitorIds;

    /**
     * Get 监控任务ID列表 
     * @return MonitorIds 监控任务ID列表
     */
    public Long [] getMonitorIds() {
        return this.MonitorIds;
    }

    /**
     * Set 监控任务ID列表
     * @param MonitorIds 监控任务ID列表
     */
    public void setMonitorIds(Long [] MonitorIds) {
        this.MonitorIds = MonitorIds;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "MonitorIds.", this.MonitorIds);

    }
}
